.. thermography.rst
.. py:module:: ludology.thermography
.. include:: definitions.rst

Thermography
============

Thermography is the study of a Game's *temperature*. Roughly, temperature is a measure of the impetus with which a player would like to move in the Game.

.. plot::

   from ludology.closet import g1
   from ludology.thermography import thermograph

   thermograph(g1)
